@@ -418,7 +418,7 @@ def _get_pairs_labels(k_level, level_names):
     """helper function for labels for pairwise comparisons
     """
     idx_pairs_all = np.triu_indices(k_level, 1)
-    labels = ['%s-%s' % (level_names[name[1]], level_names[name[0]])
+    labels = ['{}-{}'.format(level_names[name[1]], level_names[name[0]])
               for name in zip(*idx_pairs_all)]
     return labels
 
